==> nextcloud-21.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/eu.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Mahaia",
    "Dashboard app" : "Mahaia aplikazioa",
    "Show something" : "Erakutsi zerbait",
    "Customize" : "Pertsonalizatu",
    "Edit widgets" : "Editatu trepetak",
    "Get more widgets from the app store" : "Eskuratu widget gehiago aplikazio-dendatik",
    "Change background image" : "Aldatu atzeko planoko irudia",
    "Weather service" : "Eguraldi zerbitzua",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zure pribatutasunaren mesedetan, eguraldiaren datuak  Nextcloud zerbitzariak eskatzen ditu zure izenean, eguraldi zerbitzuak informazio pertsonalik ez jasotzeko.",
    "Weather data from Met.no" : "Met.no-ko eguraldiaren datuak",
    "geocoding with Nominatim" : "Geokodetzen Nominatim-ekin",
    "elevation data from OpenTopoData" : "Altitude datuak OpenTopoData-tik",
    "Weather" : "Eguraldia",
    "Status" : "Egoera",
    "Good morning" : "Egunon",
    "Good morning, {name}" : "Egunon, {name}",
    "Good afternoon" : "Arratsaldeon",
    "Good afternoon, {name}" : "Arratsaldeon, {name}",
    "Good evening" : "Gabon",
    "Good evening, {name}" : "Gabon, {name}",
    "Hello" : "Kaixo",
    "Hello, {name}" : "Kaixo, {name}",
    "Pick from Files" : "Hautatu fitxategietatik",
    "Default images" : "Irudi lehenetsiak",
    "Plain background" : "Atzeko plano arrunta",
    "Insert from {productName}" : "Txertatu hemendik: {productName}",
    "Good night, {name}" : "Gabon, {name}",
    "Good night" : "Gabon",
    "Pick from files" : "Aukeratu fitxategietatik"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/eu.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Mahaia",
    "Dashboard app" : "Mahaia aplikazioa",
    "Show something" : "Erakutsi zerbait",
    "Customize" : "Pertsonalizatu",
    "Edit widgets" : "Editatu trepetak",
    "Get more widgets from the App Store" : "Lortu widget gehiago App Store-tik",
    "Change background image" : "Aldatu atzeko planoko irudia",
    "Weather service" : "Eguraldi zerbitzua",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Zure pribatutasunaren mesedetan, eguraldiaren datuak  Nextcloud zerbitzariak eskatzen ditu zure izenean, eguraldi zerbitzuak informazio pertsonalik ez jasotzeko.",
    "Weather data from Met.no" : "Met.no-ko eguraldiaren datuak",
    "geocoding with Nominatim" : "Geokodetzen Nominatim-ekin",
    "elevation data from OpenTopoData" : "Altitude datuak OpenTopoData-tik",
    "Weather" : "Eguraldia",
    "Status" : "Egoera",
    "Good morning" : "Egunon",
    "Good morning, {name}" : "Egunon, {name}",
    "Good afternoon" : "Arratsaldeon",
    "Good afternoon, {name}" : "Arratsaldeon, {name}",
    "Good evening" : "Gabon",
    "Good evening, {name}" : "Gabon, {name}",
    "Hello" : "Kaixo",
    "Hello, {name}" : "Kaixo, {name}",
    "Pick from Files" : "Hautatu fitxategietatik",
    "Default images" : "Irudi lehenetsiak",
    "Plain background" : "Atzeko plano arrunta",
    "Insert from {productName}" : "Txertatu hemendik: {productName}",
    "Get more widgets from the app store" : "Eskuratu widget gehiago aplikazio-dendatik"
},
"nplurals=2; plural=(n != 1);");
